@@ -23,13 +23,17 @@ SIAM::ServiceDataElement - Service data element object class
 my $mandatory_attributes =
     [ 'siam.svcdata.name',
       'siam.svcdata.type',
-      'siam.svcdata.driver_class' ];
+      'siam.svcdata.driver' ];
 
 sub _mandatory_attributes
 {
     return $mandatory_attributes;
 }
 
+sub _manifest_attributes
+{
+    return $mandatory_attributes;
+}
 
 1;
 
